@@ -1,6 +1,7 @@
 from typing import TYPE_CHECKING, Optional, Tuple
 
-from .exceptions import get_status_code_error
+from . import failures
+from .exceptions import get_server_error
 from .specs.openapi.checks import (
     content_type_conformance,
     response_headers_conformance,
@@ -16,8 +17,11 @@ if TYPE_CHECKING:
 def not_a_server_error(response: GenericResponse, case: "Case") -> Optional[bool]:  # pylint: disable=useless-return
     """A check to verify that the response is not a server-side error."""
     if response.status_code >= 500:
-        exc_class = get_status_code_error(response.status_code)
-        raise exc_class(f"Received a response with 5xx status code: {response.status_code}")
+        exc_class = get_server_error(response.status_code)
+        raise exc_class(
+            f"Received a response with 5xx status code: {response.status_code}",
+            context=failures.ServerError(status_code=response.status_code),
+        )
     return None
 
 
